dm: treewide: Rename ofdata_to_platdata() to of_to_plat()

This name is far too long. Rename it to remove the 'data' bits. This makes
it consistent with the platdata->plat rename.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/dm/device-internal.h b/include/dm/device-internal.h
index 2e9c1d5..af3b6b2 100644
--- a/include/dm/device-internal.h
+++ b/include/dm/device-internal.h
@@ -89,7 +89,7 @@
 int device_reparent(struct udevice *dev, struct udevice *new_parent);
 
 /**
  * device_ofdata_to_platdata() - Read platform data for a device
  *
  * Read platform data for a device (typically from the device tree) so that
  * the information needed to probe the device is present.
@@ -102,7 +102,7 @@
  * @dev: Pointer to device to process
  * @return 0 if OK, -ve on error
  */
-int device_ofdata_to_platdata(struct udevice *dev);
+int device_of_to_plat(struct udevice *dev);
 
 /**
  * device_probe() - Probe a device, activating it
@@ -89,7 +89,7 @@
 
 /**
- * device_ofdata_to_platdata() - Read platform data for a device
+ * device_of_to_plat() - Read platform data for a device
  *
  * Read platform data for a device (typically from the device tree) so that